@@ -2,14 +2,18 @@
 
 using namespace Rcpp;
 
-RcppExport SEXP _rcpp_module_boot_multinet();
+RcppExport SEXP
+_rcpp_module_boot_multinet();
 
-static const R_CallMethodDef CallEntries[] = {
+static const R_CallMethodDef CallEntries[] =
+{
     {"_rcpp_module_boot_multinet", (DL_FUNC) &_rcpp_module_boot_multinet, 0},
     {NULL, NULL, 0}
 };
 
-RcppExport void R_init_anRpackage(DllInfo *dll) {
+RcppExport void
+R_init_anRpackage(DllInfo *dll)
+{
     R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
     R_useDynamicSymbols(dll, FALSE);
 }
